@@ -18,6 +18,7 @@ if sys.version_info < (3, 9):
     OpcodeSequence = MutableSequence
     GenericSequence = Sequence
 
+
     def make_constant(*args, **kwargs) -> ast.Constant:
         # prior to Python 3.9, the ast.Constant class did not have a `kind` member, but the `astunparse` module
         # expects that!
@@ -398,11 +399,13 @@ class Stack(GenericSequence, Generic[T]):
 
     @overload
     @abstractmethod
-    def __getitem__(self, i: int) -> T: ...
+    def __getitem__(self, i: int) -> T:
+        ...
 
     @overload
     @abstractmethod
-    def __getitem__(self, s: slice) -> GenericSequence: ...
+    def __getitem__(self, s: slice) -> GenericSequence:
+        ...
 
     def __getitem__(self, i: int) -> T:
         return self._stack[i]
@@ -760,6 +763,13 @@ class BinGet(Opcode):
         interpreter.stack.append(interpreter.memory[self.arg])
 
 
+class LongBinGet(Opcode):
+    name = "LONG_BINGET"
+
+    def run(self, interpreter: Interpreter):
+        interpreter.stack.append(interpreter.memory[self.arg])
+
+
 class Get(Opcode):
     name = "GET"
 
@@ -837,6 +847,13 @@ class BinInt2(BinInt1):
     name = "BININT2"
 
 
+class EmptySet(Opcode):
+    name = "EMPTY_SET"
+
+    def run(self, interpreter: Interpreter):
+        interpreter.stack.append(ast.Set([]))
+
+
 class EmptyList(Opcode):
     name = "EMPTY_LIST"
 
@@ -869,9 +886,43 @@ class Appends(StackSliceOpcode):
             raise ValueError(f"Expected a list on the stack, but instead found {list_obj!r}")
 
 
+class BinFloat(ConstantOpcode):
+    name = "BINFLOAT"
+
+
 class BinBytes(ConstantOpcode):
     name = "BINBYTES"
 
 
 class ShortBinBytes(BinBytes):
     name = "SHORT_BINBYTES"
+
+
+class Int(ConstantOpcode):
+    name = "INT"
+
+
+class Dict(Opcode):
+    name = "DICT"
+
+    def run(self, interpreter: Interpreter):
+        i = 0
+        keys = []
+        values = []
+
+        while interpreter.stack:
+            obj = interpreter.stack.pop()
+            if isinstance(obj, MarkObject):
+                break
+            if i == 0:
+                values.append(obj)
+            elif i == 1:
+                keys.append(obj)
+            i = (i + 1) % 2
+        else:
+            raise ValueError("Exhausted the stack while searching for a MarkObject!")
+
+        if len(keys) != len(values):
+            raise ValueError(f"Number of keys ({len(keys)}) and values ({len(values)}) for DICT do not match")            
+
+        interpreter.stack.append(ast.Dict(keys=keys, values=values))
